@@ -81,7 +81,7 @@ bool hk_kdebutton::widget_specific_open_form(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdebutton::widget_specific_open_form");
 #endif
-cerr <<"hk_kdebutton::widget_specific_open_form"<<endl;
+// cerr <<"hk_kdebutton::widget_specific_open_form"<<endl;
     hk_kdeform* w=find_existing_form();
     hk_kdeformpartwidget* f=find_existing_formpart();
 
@@ -118,10 +118,10 @@ if (p_presentation && p_presentation->name()!=object())
         hk_form* fo=dynamic_cast<hk_form*>(p_presentation);
         if (fo)
         {
-           if (s)cerr <<s->hk_form::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
+//            if (s)cerr <<s->hk_form::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
            if (s && s->formpartwidget()) s->formpartwidget()->set_caller_form(fo->name());
         }
- else cerr <<"hk_kdebutton: fo ==NULL "<<endl;
+//  else cerr <<"hk_kdebutton: fo ==NULL "<<endl;
 
 	//s->enable_datasources(true);
       }
@@ -264,7 +264,7 @@ void    hk_kdebutton::widget_specific_label_changed(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdebutton::widget_specific_label_changed");
 #endif
-    cerr <<"widget_specific_label_changed:"<<label()<<endl;
+//     cerr <<"widget_specific_label_changed:"<<label()<<endl;
     setText(QString::fromUtf8 (l2u(label()).c_str()));
     show_icon();
 }
@@ -449,7 +449,7 @@ bool hk_kdebutton::widget_specific_open_view(void)
 
 
 bool    hk_kdebutton::widget_specific_preview_report(void)
-{
+{ 
     hk_kdereport* w=find_existing_report();
     hk_kdereportpartwidget* f=find_existing_reportpart();
     if (w||f)
@@ -462,6 +462,13 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
         {
 
 	 view->activate();
+	 bool in_execute=false;
+	  if (w) in_execute=w->simplereport()->while_executing();
+	  else
+	  if (f) in_execute=f->simplereport()->while_executing();
+	  
+	 if (in_execute)
+	   return true;
         if (w)w->set_designmode();
         if (f)f->set_designmode();
         hk_string c=parsed_condition(w?w->simplereport():f->simplereport());
@@ -509,7 +516,7 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
         hk_form* fo=dynamic_cast<hk_form*>(p_presentation);
         if (fo)
         {
-           if (r)cerr <<r->hk_report::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
+//            if (r)cerr <<r->hk_report::name()<<" fo->set_caller_form: "<<fo->name()<<endl;
            if (r && r->reportpartwidget()) r->reportpartwidget()->set_caller_form(fo->name());
         }
     }
@@ -547,7 +554,7 @@ bool    hk_kdebutton::widget_specific_preview_report(void)
     }
 
 
-
+// cerr <<"PREVIEW END"<<endl;
     return true;
 }
 
@@ -624,13 +631,13 @@ void hk_kdebutton::hide_widget(void)
   hide();
 }
 
-void hk_kdebutton::close_widget(void)
+bool hk_kdebutton::close_widget(void)
 {
-  close();
+  return close();
 }
 
 bool hk_kdebutton::load_icon(const hk_string& filename,bool registerchange)
-{  cerr<<"load_icon"<<endl;
+{  //cerr<<"load_icon"<<endl;
   bool result=hk_button::load_icon(filename,registerchange);
   if (result)
   {
@@ -641,7 +648,7 @@ bool hk_kdebutton::load_icon(const hk_string& filename,bool registerchange)
 }
 
 void hk_kdebutton::show_icon()
-{cerr <<"show_icon"<<endl;
+{ //cerr <<"show_icon"<<endl;
 if (!hk_button::icon()->data) return;
    QPixmap p_pixmap;
    if (p_pixmap.loadFromData((const uchar*)hk_button::icon()->data,(uint)hk_button::icon()->length))
@@ -650,7 +657,7 @@ if (!hk_button::icon()->data) return;
      {
        hk_string d;
        data2hex(hk_button::icon(),d);
-       cerr <<d<<endl;
+//        cerr <<d<<endl;
      }
 
 }
