@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
- //$Revision: 1.4 $
+ //$Revision: 1.8 $
 #include "hk_kdedatabasesetting.h"
 #include <klocale.h>
 #include <kapplication.h>
@@ -23,11 +23,14 @@
 #include <qpixmap.h>
 #include <qstringlist.h>
 #include <qheader.h>
+#include <qlabel.h>
+#include <qwidgetstack.h>
 #include <kapplication.h>
 #include <kconfig.h>
 
 #include <hk_class.h>
 #include <hk_database.h>
+#include <hk_connection.h>
 
 
 hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,  const char* name, bool modal, WFlags fl )
@@ -53,10 +56,26 @@ hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,
   KIconLoader* loader=KGlobal::iconLoader();
   loader->addAppDir("hk_kdeclasses");
 
-  KListViewItem* item= new KListViewItem(listview,i18n("Load/Save"));
-  item->setPixmap(0,loader->loadIcon("filesave",KIcon::Desktop));
-  item->setMultiLinesEnabled(true);
+  p_systemtableitem= new KListViewItem(listview,i18n("Load/Save"));
+  p_systemtableitem->setPixmap(0,loader->loadIcon("filesave",KIcon::Desktop));
+  p_systemtableitem->setMultiLinesEnabled(true);
+  
+  if (p_database && p_database->connection()->server_needs(hk_connection::NEEDS_MANUAL_CHARSET))
+  {
+    p_localeitem=new KListViewItem(listview,i18n("Regional"));
+    p_localeitem->setPixmap(0,loader->loadIcon("locale",KIcon::Desktop));
+    p_localeitem->setMultiLinesEnabled(true);
+    for (unsigned int i=0;i<sizeof(charsets)/sizeof(hk_string);++i)
+     {
+      databaseencodingfield->insertItem(QString::fromUtf8(l2u(charsets[i]).c_str()));
+     }
+   databaseencodingfield->setCurrentText(QString::fromUtf8(l2u(p_database->databasecharset()).c_str()));
+  }
+  else 
+  p_localeitem=NULL;
   listview->header()->setLabel( 0, "",listview->width() );
+  listview->setCurrentItem(p_systemtableitem);
+  p_systemtableitem->setSelected(true);
   if (!p_database) return;
   
 
@@ -68,6 +87,8 @@ hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,
   
   reportload->setCurrentItem(p_database->loadmode(ft_report)==hk_database::central?1:0);
   reportstore->setCurrentItem(p_database->storagemode(ft_report)==hk_database::central?1:0);
+  
+  automaticupdatefield->setCurrentItem(p_database->default_automatic_data_update()?0:1);
   selection_changed();
   ok_button->setEnabled(false);
  KConfig* c=kapp->config();
@@ -76,7 +97,6 @@ hk_kdedatabasesetting::hk_kdedatabasesetting( hk_database*db, QWidget* parent,
   QRect g;
   g=c->readRectEntry("Geometry",&rect);
   setGeometry(g);
-  
 }
 
 hk_kdedatabasesetting::~hk_kdedatabasesetting()
@@ -97,7 +117,8 @@ void hk_kdedatabasesetting::create_clicked()
 void hk_kdedatabasesetting::selection_changed()
 {
 bool hasstorage=p_database->has_centralstoragetable();
-createbutton->setEnabled(!hasstorage);
+createbutton->setEnabled(!hasstorage && p_database&&p_database->connection()->server_supports(hk_connection::SUPPORTS_NEW_TABLE)
+);
 storageframe->setEnabled(hasstorage);
 ok_button->setEnabled(true);
 }
@@ -127,6 +148,8 @@ ok_button->setEnabled(true);
 
 void hk_kdedatabasesetting::listview_changed()
 {
+  widgetstack->raiseWidget(listview->currentItem()==p_localeitem?1:0);
+      headertext->setText( listview->currentItem()==p_localeitem?tr("Regional"):tr( "Open and store files:" ) );
 
 }
 
@@ -138,6 +161,11 @@ void hk_kdedatabasesetting::ok_clicked()
                                   ((formstore->currentItem()==1)?hk_database::central:hk_database::local));
  p_database->set_storagemode(ft_report, ((reportload->currentItem()==1)?hk_database::central:hk_database::local),
                                   ((reportstore->currentItem()==1)?hk_database::central:hk_database::local));
+ p_database->set_automatic_data_update(automaticupdatefield->currentItem()==0); 
+    if (p_database && p_database->connection()->server_needs(hk_connection::NEEDS_MANUAL_CHARSET))
+  {
+  p_database->set_databasecharset(l2u(databaseencodingfield->currentText().utf8().data()));
+  }
   
  p_database->save_configuration(); 
    KConfig* c=kapp->config();
@@ -146,3 +174,7 @@ void hk_kdedatabasesetting::ok_clicked()
   accept();
 }
 
+void hk_kdedatabasesetting::encoding_changed()
+{
+ ok_button->setEnabled(true);
+}
