@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.45 $
+//$Revision: 1.51 $
 #include <assert.h>
 #include "hk_kdedbdesigner.h"
 #include "hk_kdeformdatasourcedialog.h"
@@ -43,6 +43,9 @@
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kaccelmanager.h>
+#include <kglobal.h>
+#include <kiconloader.h>
+
 
 const int designwidth=3000;
 const int designheight=3000;
@@ -398,6 +401,9 @@ hk_kdedatasourceframe::hk_kdedatasourceframe(hk_kdedbdesigner* designer,QWidget*
 	p_layout->addWidget(mv,2,1);
 
 	p_positionupdate=true;
+    KIconLoader* loader=KGlobal::iconLoader();
+    loader->addAppDir("hk_kdeclasses");
+    keyicon=loader->loadIcon("key",KIcon::User);
 	set_fields();
 	if (ds)
 	{
@@ -446,7 +452,13 @@ void hk_kdedatasourceframe::set_fields(void)
 	  list<hk_string>::iterator it=cols->begin();
 	  while (it!=cols->end())
 	  {
-	  	p_listbox->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
+	  	hk_column* c=datasource()->column_by_name(*it);
+	  	if (c &&c->is_primary())
+	  	{
+	  	  p_listbox->insertItem(keyicon,QString::fromUtf8(l2u((*it)).c_str()));
+	  	}
+	  	else
+	  	  p_listbox->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
 		++it;
 	  }
 	  set_header();
@@ -694,12 +706,12 @@ return NULL;
 
 hk_kdedbrelation* hk_kdedbdesigner::get_relation(hk_datasource* ds)
 {
-  if (!ds) return NULL; cerr<<"get_relation:"<<ds->name()<<endl;
+  if (!ds) return NULL; 
   list<hk_kdedbrelation*>::iterator it=p_private->p_relationlist.begin();
 while (it!=p_private->p_relationlist.end())
   	{
 	   if ((*it)->masterdatasource()->datasource()==ds|| (*it)->slavedatasource()->datasource()==ds)
-	   	{cerr <<"gefundene Relation"<<endl;
+	   	{
 		  return (*it);
 		}
 	   ++it;
@@ -867,7 +879,11 @@ hk_kdedbrelation* hk_kdedbdesigner::add_relation(hk_kdedatasourceframe* master,
   if (slave&&slave->datasource()&&slave->datasource()->depending_on())
     {
        hk_kdedbrelation* r=get_relation(slave->datasource()->depending_on(),slave->datasource());
-       if (r) delete_relation(r);
+       if (r) 
+       {
+
+        delete_relation(r);
+       }
 
     }
 
@@ -958,7 +974,7 @@ void hk_kdedbdesigner::delete_datasource(hk_kdedatasourceframe* f)
    	 ++it;
     	}*/
    while((rel=get_relation(f->datasource())))
-   {  cerr <<"REL: aus get_relation:"<<rel<<endl;
+   {  
       if (rel) remove_relation(rel);
    }
   }
@@ -1104,6 +1120,7 @@ emit signal_field_doubleclicked(t,c);
 hk_kdedbrelation::hk_kdedbrelation(QWidget* parent,bool is_integrity):QWidget(parent),hk_class()
 {
 p_tox=p_toy=p_fromx=p_fromy=0;
+p_masterdatasource=p_slavedatasource=NULL;
 p_is_focused=false;
 setMouseTracking(true);
 setFocusPolicy(StrongFocus);
@@ -1125,6 +1142,10 @@ void hk_kdedbrelation::paint_relation(QPainter* paint)
    paint->drawLine(0,0,0,height());
    paint->drawLine(width()-1,0,width()-1,height());
 */
+   hk_datasource* sd=(p_slavedatasource?p_slavedatasource->datasource():NULL);
+   bool paint_arrow=(sd && sd->depending_on_is_left_join());
+
+    
     QPen p=paint->pen();
    if (p_is_focused)
    {
@@ -1140,18 +1161,27 @@ void hk_kdedbrelation::paint_relation(QPainter* paint)
    paint->drawLine(p_fromx,p_fromy+1,p_fromx+hlength,p_fromy+1);//master horizontal
    p.setWidth(pw);
    paint->setPen(p);
-
    paint->drawLine(p_tox-hlength,p_toy+arrowheight,  p_tox ,p_toy+arrowheight);//slave horizontal
+//     p.setWidth(pw);
+//    paint->setPen(p);
    if (p_is_focused)
    {
     QPen p=paint->pen();
     p.setWidth(0);
     paint->setPen(p);
    }
-   QPointArray array;
-   array.setPoints(3,p_tox-1,p_toy+arrowheight, p_tox-arrowlength-1,p_toy,p_tox-arrowlength-1,p_toy+2*arrowheight);
-   paint->drawPolygon(array);
-
+//    hk_datasource* sd=(p_slavedatasource?p_slavedatasource->datasource():NULL);
+   if (paint_arrow)
+   {
+     QPointArray array;
+     array.setPoints(3,p_tox-1,p_toy+arrowheight, p_tox-arrowlength-1,p_toy,p_tox-arrowlength-1,p_toy+2*arrowheight);
+     paint->drawPolygon(array);
+   }
+   else
+   {
+    paint->drawEllipse(p_tox-hlength/2,p_toy,hlength,hlength);
+   }
+   
    paint->restore();
 }
 
@@ -1335,7 +1365,7 @@ p_toy=0;
 if (h<3)h=3;
 if (w<3)w=3;
 
-setGeometry(x,y+5,w+5,h+10);
+setGeometry(x,y+10,w+10,h+20);
 
 }
 
@@ -1416,11 +1446,11 @@ id[1]=context->insertItem(i18n("Edit"));
 id[2]=context->insertItem(i18n("Delete"));
 int res=context->exec(QCursor::pos());
 
-if (res==id[0])
+/*if (res==id[0])
 	{
 
 	}
-else
+else*/
 if (res==id[1])
 	{
       	  edit();
