@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
- //$Revision: 1.9 $
+ //$Revision: 1.11 $
 
 #ifndef HK_KDEDBLISTVIEW_H
 #define HK_KDEDBLISTVIEW_H
@@ -69,6 +69,16 @@ bool is_formitem(bool includingheader=false);
 bool is_reportitem(bool includingheader=false);
 bool is_databaseitem(void);
 bool is_headeritem(void);
+bool is_tableheader(void);
+bool is_queryheader(void);
+bool is_viewheader(void);
+bool is_formheader(void);
+bool is_reportheader(void);
+bool is_tableheader(QListViewItem*);
+bool is_queryheader(QListViewItem*);
+bool is_viewheader(QListViewItem*);
+bool is_formheader(QListViewItem*);
+bool is_reportheader(QListViewItem*);
 bool cancel(void){return p_cancelcopying;}
 void reload_lists(void);
 enum enum_showmode {sm_all,sm_central,sm_local};
@@ -76,12 +86,17 @@ enum enum_showmode {sm_all,sm_central,sm_local};
 void set_showmode(enum_showmode);
 enum_showmode showmode(void) const;
 
+static void set_use_singleclick(bool);
+static bool use_singleclick(void) ;
+
+
+
 signals:
 
  void signal_new_database(void);
  void signal_delete_database(const QString&);
  void signal_reload_databases(void);
- 
+
  void signal_new_table(void);
  void signal_delete_table(const QString&);
  void signal_designmode_table(const QString&);
@@ -116,24 +131,27 @@ virtual void delete_clicked();
         void copy(void);
         void paste(void);
         void copying_cancelled();
-        
+
 
 protected slots:
 
- void item_clicked(QListViewItem*);
+void item_clicked(QListViewItem*);
 void item_doubleclicked(QListViewItem*);
 void slot_drop(QDropEvent*);
+
+
 protected:
 static  bool set_progress(long int,long int,const hk_string&);
         QDragObject* dragObject ();
 
+        void item_selected(QListViewItem* );
 virtual void list_changes(listtype type);
- 
+
 // virtual void contentsmouseReleaseEvent(QMouseEvent*);
 // virtual void contentsmouseMoveEvent(QMouseEvent*);
  virtual bool acceptDrag(QDropEvent*) const;
  //void dragEnterEvent(QDragEnterEvent*);
- 
+
  bool decode_action(QMimeSource* event);
  bool copy_presentationfile(void);
  bool copy_table(void);
@@ -154,6 +172,7 @@ bool execute_action(void);
 hk_kdedblistviewprivate* p_private;
 static QProgressDialog* p_progressdialog;
 static bool p_cancelcopying;
+static bool p_use_singleclick;
 };
 
 class hk_kdeschemadialog : public QDialog
