@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.36 $
+//$Revision: 1.38 $
 #include "hk_kdeformdatasourcedialog.h"
 #include <hk_class.h>
 #include <hk_form.h>
@@ -54,6 +54,7 @@ hk_kdeformdatasourcedialog::hk_kdeformdatasourcedialog( hk_presentation* p, QWid
     p_private->p_edittype=e_all;
     p_private->p_clickedbutton=cb_cancel;
     set_datasource(NULL);
+    automaticupdatefield->setChecked(true);
     KIconLoader* loader=KGlobal::iconLoader();
     loader->addAppDir("hk_kdeclasses");
     dependingfieldlist->addColumn(i18n("thisfield"));
@@ -141,7 +142,7 @@ void hk_kdeformdatasourcedialog::set_datasourcelist()
     vector<hk_string>::iterator it=v->begin();
     while (it!=v->end())
     {
-        datasourcefield->insertItem(QString::fromLocal8Bit ((*it).c_str()));
+        datasourcefield->insertItem(QString::fromUtf8 (l2u((*it)).c_str()));
         it++;
     }
     datasourcefield->setCurrentItem(0);
@@ -170,7 +171,7 @@ void hk_kdeformdatasourcedialog::datasource_selected()
       if (sourcetypefield->currentText()==txt) dt=dt_view;
     }  
     
-    hk_datasource* ds= db->load_datasource(datasourcefield->currentText().local8Bit().data(),dt);
+    hk_datasource* ds= db->load_datasource(u2l(datasourcefield->currentText().utf8().data()),dt);
     if (ds==NULL) return;
     sqlfield->setEnabled(false);
     if (dt==dt_query&& datasourcefield->currentText().isEmpty())  sqlfield->setEnabled(true);
@@ -182,7 +183,7 @@ void hk_kdeformdatasourcedialog::datasource_selected()
 
     }
     sqlfield->blockSignals(true);
-    sqlfield->setText(QString::fromLocal8Bit(ds->sql().c_str()));
+    sqlfield->setText(QString::fromUtf8(l2u(ds->sql()).c_str()));
     sqlfield->blockSignals(false);
     list<hk_column*>* v=ds->columns();
 
@@ -195,7 +196,7 @@ void hk_kdeformdatasourcedialog::datasource_selected()
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        thisfield->insertItem(QString::fromLocal8Bit ((*it)->name().c_str()));
+        thisfield->insertItem(QString::fromUtf8 (l2u((*it)->name()).c_str()));
         it++;
     }
     delete ds;
@@ -231,7 +232,7 @@ void hk_kdeformdatasourcedialog::dependingon_selected()
     list<hk_datasource*>::iterator nit=dslist->begin();
     while (nit!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit (p_private->p_presentation->unique_datasourcename((*nit)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8 (l2u(p_private->p_presentation->unique_datasourcename((*nit)->presentationnumber())).c_str());
         if (name==dependingonfield->currentText())
         {
             ds=p_private->p_presentation->get_datasource((*nit)->presentationnumber()) ;
@@ -267,7 +268,7 @@ void hk_kdeformdatasourcedialog::dependingon_selected()
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        masterfield->insertItem(QString::fromLocal8Bit ((*it)->name().c_str()));
+        masterfield->insertItem(QString::fromUtf8 (l2u((*it)->name()).c_str()));
         it++;
     }
 
@@ -292,7 +293,7 @@ void hk_kdeformdatasourcedialog::set_formdatasources(void)
     dependingonfield->insertItem("");
     while (it!=dslist->end())
     {
-        QString name= QString::fromLocal8Bit (p_private->p_presentation->unique_datasourcename((*it)->presentationnumber()).c_str());
+        QString name= QString::fromUtf8 (l2u(p_private->p_presentation->unique_datasourcename((*it)->presentationnumber())).c_str());
         dependingonfield->insertItem(name);
         it++;
     }
@@ -344,7 +345,7 @@ void hk_kdeformdatasourcedialog::set_datasourceinfos(bool existingdatasource)
 
     if (!existingdatasource)
     {
-        long  id =p_private->p_presentation->new_datasource(datasourcefield->currentText().local8Bit().data(),dt);
+        long  id =p_private->p_presentation->new_datasource(u2l(datasourcefield->currentText().utf8().data()),dt);
         d=p_private->p_presentation->get_datasource(id);
 	p_private->p_datasource=d;
     }
@@ -355,19 +356,20 @@ void hk_kdeformdatasourcedialog::set_datasourceinfos(bool existingdatasource)
         d->clear_sorting();
         d->set_readonly(readonlyfield->isChecked());
 	d->set_depending_on_presentationdatasource(-1);
+        d->set_automatic_data_update(automaticupdatefield->isChecked());
 	if (d->name().length()==0)
-		d->set_sql(sqlfield->text().local8Bit().data());
+		d->set_sql(u2l(sqlfield->text().utf8().data()));
 
         if (sortingfield->text().length()>0)
         {
-            hk_string s = sortingfield->text().local8Bit().data();
+            hk_string s = u2l(sortingfield->text().utf8().data());
             d->set_sorting(s);
         }
-        if (filterfield->text().length()>0) d->set_filter(filterfield->text().local8Bit().data());
+        if (filterfield->text().length()>0) d->set_filter(u2l(filterfield->text().utf8().data()));
         if (dependingonfield->currentText().length()>0 && dependingfieldlist->childCount()>0)
         {
 
-            hk_datasource* depds=p_private->p_presentation->get_datasource(dependingonfield->currentText().local8Bit().data());
+            hk_datasource* depds=p_private->p_presentation->get_datasource(u2l(dependingonfield->currentText().utf8().data()));
             if (depds!=NULL)
             {
                 hk_datasource::enum_dependingmodes mode=hk_datasource::depending_standard;
@@ -385,7 +387,7 @@ void hk_kdeformdatasourcedialog::set_datasourceinfos(bool existingdatasource)
                 {
                     QString st1 = i->text(0);
                     QString st2 = i->text(1);
-                    d->add_depending_fields(st1.local8Bit().data(),st2.local8Bit().data());
+                    d->add_depending_fields(u2l(st1.utf8().data()),u2l(st2.utf8().data()));
                     i=i->itemBelow();
                 }
             }
@@ -416,10 +418,10 @@ void hk_kdeformdatasourcedialog::set_datasource(hk_datasource* d)
 
     alterbutton->setEnabled(true);
     deletebutton->setEnabled(true);
-    filterfield->setText(QString::fromLocal8Bit (p_private->p_datasource->filter().c_str()));
-    sortingfield->setText(QString::fromLocal8Bit (p_private->p_datasource->sorting().c_str()));
+    filterfield->setText(QString::fromUtf8 (l2u(p_private->p_datasource->filter()).c_str()));
+    sortingfield->setText(QString::fromUtf8 (l2u(p_private->p_datasource->sorting()).c_str()));
     readonlyfield->setChecked(p_private->p_datasource->is_readonly());
-
+    automaticupdatefield->setChecked(p_private->p_datasource->is_automatic_data_update());
     switch (p_private->p_datasource->type())
     {
     case hk_data::ds_table: sourcetypefield->setCurrentItem(0);break;
@@ -429,7 +431,7 @@ void hk_kdeformdatasourcedialog::set_datasource(hk_datasource* d)
     
     set_datasourcelist();
     int c=0;
-    QString t=QString::fromLocal8Bit (p_private->p_datasource->name().c_str());
+    QString t=QString::fromUtf8 (l2u(p_private->p_datasource->name()).c_str());
     while (c<datasourcefield->count())
     {
         if (datasourcefield->text(c)==t)
@@ -443,14 +445,14 @@ void hk_kdeformdatasourcedialog::set_datasource(hk_datasource* d)
     react_on_changesfield->setChecked(p_private->p_datasource->depending_on_react_on_data_changes());
 
     sqlfield->blockSignals(true);
-    sqlfield->setText(QString::fromLocal8Bit(p_private->p_datasource->sql().c_str()));
+    sqlfield->setText(QString::fromUtf8(l2u(p_private->p_datasource->sql()).c_str()));
     sqlfield->blockSignals(false);
 
     hk_datasource* depds=p_private->p_datasource->depending_on();
     if ( depds==NULL) return;
 
     c=0;
-    t=QString::fromLocal8Bit (p_private->p_presentation->unique_datasourcename(depds->presentationnumber()).c_str());
+    t=QString::fromUtf8 (l2u(p_private->p_presentation->unique_datasourcename(depds->presentationnumber())).c_str());
     while (c<dependingonfield->count())
     {
         if (dependingonfield->text(c)==t)
@@ -469,7 +471,7 @@ void hk_kdeformdatasourcedialog::set_datasource(hk_datasource* d)
     QListViewItem* item= NULL;
     while ((this_it!=thislist->end())&&(master_it!=masterlist->end()))
     {
-        item=new QListViewItem(dependingfieldlist,QString::fromLocal8Bit ((*this_it).c_str()),QString::fromLocal8Bit ((*master_it).c_str()));
+        item=new QListViewItem(dependingfieldlist,QString::fromUtf8 (l2u((*this_it)).c_str()),QString::fromUtf8 (l2u((*master_it)).c_str()));
         master_it++;
         this_it++;
     }
