@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.27 $
+//$Revision: 1.30 $
 
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -67,6 +67,7 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     hkdebug("hk_kdeformpartwidget::hk_kdeformpartwidget");
 #endif
     p_formpart=formpart;
+    p_dontclose=false;
     setFocusPolicy(StrongFocus);
     KIconLoader* loader=KGlobal::iconLoader();
     loader->addAppDir("hk_kdeclasses");
@@ -126,17 +127,17 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
     p_saveasaction=new KAction(i18n("Save &as"),"filesaveas",0,this,SLOT(saveas_form()),formpart->actionCollection(),"saveas");
     p_saveasaction->setEnabled(!runtime_only());
 
-    p_lineeditaction=new KRadioAction("Lineedit",loader->loadIcon("edit",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"lineedit");
-    p_pointeraction=new KRadioAction("Pointer",loader->loadIcon("pfeil",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"pointer");
-    p_labelaction=new KRadioAction("Label",loader->loadIcon("label",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"label");
-    p_multilineeditaction=new KRadioAction("Multiline",loader->loadIcon("multiline",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"multiline");
-    p_booleanaction=new KRadioAction("Boolean",loader->loadIcon("boolean22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"boolean");
-    p_comboboxaction=new KRadioAction("Combobox",loader->loadIcon("combobox22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"combobox");
-    p_gridaction=new KRadioAction("Grid",loader->loadIcon("grid22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"grid");
-    p_selectoraction=new KRadioAction("Selector",loader->loadIcon("rowselector22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"selector");
-    p_buttonaction=new KRadioAction("Button",loader->loadIcon("button",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"button");
-    p_subformaction=new KRadioAction("Subform","openterm",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"subform");
-    p_imageaction=new KRadioAction("Image",loader->loadIcon("image",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"image");
+    p_lineeditaction=new KRadioAction(i18n("Lineedit"),loader->loadIcon("edit",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"lineedit");
+    p_pointeraction=new KRadioAction(i18n("Pointer"),loader->loadIcon("pfeil",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"pointer");
+    p_labelaction=new KRadioAction(i18n("Label"),loader->loadIcon("label",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"label");
+    p_multilineeditaction=new KRadioAction(i18n("Multiline"),loader->loadIcon("multiline",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"multiline");
+    p_booleanaction=new KRadioAction(i18n("Boolean"),loader->loadIcon("boolean22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"boolean");
+    p_comboboxaction=new KRadioAction(i18n("Combobox"),loader->loadIcon("combobox22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"combobox");
+    p_gridaction=new KRadioAction(i18n("Grid"),loader->loadIcon("grid22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"grid");
+    p_selectoraction=new KRadioAction(i18n("Selector"),loader->loadIcon("rowselector22x22",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"selector");
+    p_buttonaction=new KRadioAction(i18n("Button"),loader->loadIcon("button",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"button");
+    p_subformaction=new KRadioAction(i18n("Subform"),"openterm",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"subform");
+    p_imageaction=new KRadioAction(i18n("Image"),loader->loadIcon("image",KIcon::User),0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"image");
     p_tabwidgetaction=new KRadioAction("Tabwidget","",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"tabwidget");
     p_dateaction=new KRadioAction("date","kontact_date",0,this,SLOT(fieldbutton_clicked()),formpart->actionCollection(),"date");
     p_bulkaction=new KActionMenu(i18n("Set to all"),0,formpart->actionCollection(),"bulk");
@@ -247,7 +248,7 @@ hk_kdeformpartwidget::~hk_kdeformpartwidget()
 #ifdef HK_DEBUG
     hkdebug("hk_kdeformpartwidget::~hk_kdeformpartwidget");
 #endif
-   cerr <<p_form->hk_form::name()<<" callerform:"<<caller_form()<<endl;
+//    cerr <<p_form->hk_form::name()<<" callerform:"<<caller_form()<<endl;
      emit signal_raise_form(caller_form());
     delete p_rowselector;
 }
@@ -524,6 +525,11 @@ void hk_kdeformpartwidget::closeEvent ( QCloseEvent* e)
     hkdebug("hk_kdeformpartwidget::closeEvent");
 //set_generaldebug(true);
 #endif
+if (p_dontclose || p_form->while_load_form()) 
+  {
+    e->ignore();
+    return;
+  }
 save_form_when_changed();
  #ifdef HK_DEBUG
     hkdebug("hk_kdeformpartwidget::closeEvent nach abspeichern");
@@ -589,10 +595,12 @@ void hk_kdeformpartwidget::load_form(const hk_string& n)
 
     }
 //  p_form->formname(n);
+p_dontclose=true;
     p_form->load_form(n);
     p_rowselector->set_presentationdatasource(p_form->presentationdatasource(),false);
     if (p_form->datasource())toolbar->set_filter(QString::fromUtf8(l2u(p_form->datasource()->temporaryfilter()).c_str()));
     set_caption();
+p_dontclose=false;
 }
 
 
@@ -826,9 +834,9 @@ void hk_kdeformpartwidget::hide_widget(void)
   hide();
 }
 
-void hk_kdeformpartwidget::close_widget(void)
+bool hk_kdeformpartwidget::close_widget(void)
 {
-  close();
+  return close();
 }
 
 
