@@ -38,7 +38,7 @@ class hk_kdeformpart;
  *
  *@short  KDE high level widget to display and design forms
  *@author Horst Knorr (hk_classes@knoda.org)
- *@version $Revision: 1.12 $
+ *@version $Revision: 1.14 $
  *
  *this is a high level widget to display and design forms. It hereby uses @ref hk_kdesimpleform.
  *To use it set the database with @ref set_database. If you want to show or edit an existing form
@@ -126,7 +126,7 @@ class hk_kdeformpartwidget : public KDockMainWindow,public hk_class
         void set_caption(void);
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
         void set_caller_form(const hk_string&);
         hk_string caller_form(void) const;
 
@@ -213,5 +213,6 @@ virtual void close_widget(void);
         hk_kderowselector* p_rowselector;
         QScrollView* p_scrollview;
         bool p_nodesignmode;
+        bool p_dontclose;
 };
 #endif
