@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.36 $
+// $Revision: 1.37 $
 
 #include "hk_kdegridcolumndialog.h"
 
@@ -153,10 +153,10 @@ void hk_kdegridcolumndialog::deletebutton_clicked()
     QListViewItem* f=rightbox->currentItem();
 
 //QListViewItem* p=NULL;
-    if (f==NULL||p_currentfieldit==NULL)  return;
+    if (f==NULL||p_currentfieldit==fields.end())  return;
     f->itemBelow();
 
-    if (p_currentfieldit!=fields.end()&&p_currentfieldit!=NULL)
+    if (p_currentfieldit!=fields.end())
     {
         fields.erase(p_currentfieldit);
         p_currentfieldit=fields.end();
