@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.35 $
+//$Revision: 1.39 $
 
 #include "hk_kdemessages.h"
 #include <kmessagebox.h>
@@ -19,6 +19,8 @@
 
 #include <klocale.h>
 #include <kfiledialog.h>
+#include <kdirselectdialog.h>
+
 #include "hk_kdedriverdialog.h"
 #include "hk_kdeform.h"
 #include "hk_kdesimpleform.h"
@@ -125,13 +127,13 @@ void hk_kdetextdialog::languageChange()
 
 void hk_kdetextdialog::text_changed(const QString& t)
 {
-hk_string txt=trim(t.local8Bit().data());
+hk_string txt=trim(u2l(t.utf8().data()));
 buttonOk->setEnabled(txt.size()>0);
 }
 
 void hk_kdewarning(const hk_string& w)
 {
-    KMessageBox::information(0,QString::fromLocal8Bit (w.c_str()),i18n("Information"),0,0);
+    KMessageBox::information(0,QString::fromUtf8 (l2u(w).c_str()),i18n("Information"),0,0);
 }
 
 
@@ -139,7 +141,7 @@ bool hk_kdeyesno_dialog(const hk_string& w,bool )
 {
     int ret;
     QString a=i18n("Please decide");
-    ret=KMessageBox::questionYesNo(0,QString::fromLocal8Bit (w.c_str()),a);
+    ret=KMessageBox::questionYesNo(0,QString::fromUtf8 (l2u(w).c_str()),a);
     if (ret==3)    return true;
     else    return false;
 }
@@ -149,11 +151,11 @@ hk_string hk_kdestringvaluedialog(const hk_string& st)
 {
     //bool ok;
     hk_kdetextdialog* txtdlg=new hk_kdetextdialog(0,0,true);
-    txtdlg->textlabel->setText(QString::fromLocal8Bit(st.c_str()));
+    txtdlg->textlabel->setText(QString::fromUtf8(l2u(st).c_str()));
     txtdlg->exec();
     if (txtdlg->result()==QDialog::Accepted)
     {
-        return trim(txtdlg->textfield->text().local8Bit().data());
+        return trim(u2l(txtdlg->textfield->text().utf8().data()));
     }
     else return "";
 }
@@ -170,7 +172,7 @@ bool hk_kdenewpassworddlg(hk_string& s)
     {
         if (dlg->passwordfield->text()==dlg->repeatfield->text())
         {
-            s=dlg->passwordfield->text().local8Bit().data();
+            s=u2l(dlg->passwordfield->text().utf8().data());
             delete dlg;
             return true;
         }
@@ -204,10 +206,10 @@ hk_form* new_form(hk_database* db,hk_class* parent)
    part->show();
    return part->simpleform();
   }
-  
+
   hk_kdeform* f=new hk_kdeform(dynamic_cast<QWidget*>(parent),0,QWidget::WDestructiveClose);
-  
-  
+
+
   if (!f) return NULL;
   f->set_database(db);
   f->set_designmode();
@@ -245,11 +247,11 @@ hk_report* new_report(hk_database* db,hk_class* parent)
 
 hk_form* new_dialogform(hk_database* db,hk_class* )
 {
-  
-  
+
+
   hk_kdesimpleform* f=new hk_kdesimpleform(qApp->mainWidget(),0,Qt::WType_Dialog);
-  
-  
+
+
   if (!f) return NULL;
   f->set_database(db);
   f->set_designmode();
@@ -281,7 +283,7 @@ hk_dstable* new_table(hk_class* parent)
   if (!f) return NULL;
   if (hk_visible::open_maximized_windows())f->showMaximized();
   else f->show();
-  
+
   return f;
   }
 }
@@ -303,7 +305,7 @@ hk_dsquery* new_query(hk_class* parent)
   if (!f) return NULL;
   if (hk_visible::open_maximized_windows())f->showMaximized();
   else f->show();
-  
+
   return f;
   }
 }
@@ -314,18 +316,35 @@ hk_string hk_kdefiledialog(const hk_string&  url,enum_operationmode mode)
 {
 hk_string result;
 hk_url u=url;
-KFileDialog* d=new KFileDialog(u.directory().size()>0?QString::fromLocal8Bit(u.directory().c_str()):QString::null,
+KFileDialog* d=new KFileDialog(u.directory().size()>0?QString::fromUtf8(l2u(u.directory()).c_str()):QString::null,
 			QString::null,0,0,true);
 if (mode==file_save) d->setOperationMode(KFileDialog::Saving);
 d->exec();
 QString filename=d->selectedFile();
   if (!filename.isNull())
-     result=filename.local8Bit().data();
+     result=u2l(filename.utf8().data());
 delete d;
  return result;
 }
 
 
+hk_string hk_kdedirectorydialog(const hk_string& url)
+{
+hk_string result;
+KDirSelectDialog* d=new KDirSelectDialog(url.size()>0?QString::fromUtf8(l2u(url).c_str()):QString::null,true);
+ if (d->exec()==QDialog::Accepted)
+ {
+  KURL dir=d->url();
+  if (!dir.path().isNull())
+     result=u2l(dir.path().utf8().data());
+ }
+ else
+   result=url;
+delete d;
+ return result;
+
+}
+
 
 
 
@@ -344,6 +363,7 @@ void set_kdestandarddialogs(void)
     hk_database::set_new_tablevisiblefunction(&new_table);
     hk_database::set_new_queryvisiblefunction(&new_query);
     hk_database::set_filedialog(&hk_kdefiledialog);
+    hk_database::set_directorydialog(&hk_kdedirectorydialog);
    // hk_datasource::set_enablefunction(&hk_kdedatasourceenablefunction,10000);
 
 }
@@ -361,7 +381,7 @@ void hk_kdepassworddlg(hk_connection* connection,struct_connectionfields* c)
 hk_string hk_kdetranslate(const hk_string& t)
 {
     QString erg=i18n(t.c_str());
-    return (erg.local8Bit().data());
+    return (u2l(erg.utf8().data()));
 }
 
 
@@ -373,3 +393,39 @@ hk_string hk_kdedriverselectdialog(void)
     delete c;
     return p;
 }
+
+
+hk_string mimetype2driver(const hk_string& mimename)
+{
+  hk_string driver;
+  if (mimename=="application/x-hk_classes-sqlite3"||mimename=="application/x-sqlite3"
+      ||mimename=="application/x-kexiproject-sqlite3")
+    {
+      driver="sqlite3";
+    }
+    else
+    if (mimename=="application/x-hk_classes-sqlite2"||mimename=="application/x-sqlite2"
+      ||mimename=="application/x-kexiproject-sqlite2")
+    {
+     driver="sqlite2";
+    }
+
+    else
+    if (mimename=="application/x-msaccess")
+    {
+     driver="mdb";
+    }
+
+    else
+    if (mimename=="application/x-dbase")
+    {
+     driver="xbase";
+    }
+    else
+    if (mimename=="application/x-paradox")
+    {
+     driver="paradox";
+    }
+
+  return driver;
+}
