@@ -36,27 +36,55 @@ protected:
 bool delete_rows(void)
 	{
 	  QMemArray<int> myarray(0);
-	  int i=0; int col=0;
+	  int i=0; //int col=0;
 	  int leftcol=999;
+	  if (numSelections()==0)
+	  {
+	        QTableItem* itm=item(currentRow(),currentColumn());
+	        if (itm)
+	         {
+	           if(itm->rtti()==1)
+	           ((QComboTableItem*) (itm))->setCurrentItem(0);
+	          else clearCell(currentRow(),currentColumn());
+	         }
+	  }
+	  else
+	  {
 	  while (i<numSelections())
 	  {
-	  QTableSelection s=selection(i);
-	  if (isColumnSelected(s.leftCol(),true))
-	  {
-	   myarray.resize(myarray.size()+s.numCols());
-	   if (s.leftCol()<leftcol)leftcol=s.leftCol();
-	   for (int c=s.leftCol();c<=s.rightCol();++c)
+	     QTableSelection s=selection(i);
+	     /*if (isColumnSelected(s.leftCol(),true))
+	     {
+	     myarray.resize(myarray.size()+s.numCols());
+	     if (s.leftCol()<leftcol)leftcol=s.leftCol();
+	     for (int c=s.leftCol();c<=s.rightCol();++c)
 	     {
 	      myarray[col]=c;
 	      ++col;
 	     }
-	  }
-	  ++i;
-	  }
-	  myarray.sort();
-	  if (myarray.size()==0) return false;
-	  removeColumns(myarray);
-         setCurrentCell(currentRow(),leftcol);
+	     }*/
+	     for (int c=s.leftCol();c<=s.rightCol();++c)
+	     {
+	      for (int r=s.topRow();r<=s.bottomRow();++r)
+	       {
+	        QTableItem* itm=item(r,c);
+	        if (itm)
+	         {
+	           if(itm->rtti()==1)
+	           ((QComboTableItem*) (itm))->setCurrentItem(0);
+	          else clearCell(r,c);
+	         }
+	       }
+	     }
+	     
+	    ++i;
+	   }
+	  
+	   myarray.sort();
+	   if (myarray.size()==0) return false;
+	   removeColumns(myarray);
+           setCurrentCell(currentRow(),leftcol);
+         }
  	 p_qbe->slot_has_changed();
 	 return true;
 	}
