@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.23 $
+//$Revision: 1.24 $
 
 #include "hk_kdequerypartwidget.h"
 #include "hk_kdequerypartwidget.moc"
@@ -875,9 +875,9 @@ void hk_kdequerypartwidget::hide_widget(void)
   hide();
 }
 
-void hk_kdequerypartwidget::close_widget(void)
+bool hk_kdequerypartwidget::close_widget(void)
 {
-  close();
+  return close();
 }
 
 
