@@ -39,7 +39,7 @@ class hk_kdequerypartwidgetprivate;
 /**
  *
  *@short KDE high level widget to define queries and see the result.
- *@version $Revision: 1.10 $
+ *@version $Revision: 1.11 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *hk_kdequerypartwidget is a high level widget to define queries and see the result.
@@ -82,7 +82,7 @@ virtual        ~hk_kdequerypartwidget();
 virtual	void reset_has_changed(void);
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
 
     signals:
         void signal_closed(QWidget*);
