@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.18 $
+//$Revision: 1.20 $
 
 #include "hk_kdereportpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -397,7 +397,12 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
     hkdebug("hk_kdereportpartwidget::set_mode(s)");
 #endif
     //if (s==p_report->mode()&&!runtime_only())return;
-
+   if (p_report->while_executing() && s==hk_presentation::designmode)
+   {
+    if (p_viewaction)p_viewaction->setChecked(true);
+    return;
+   }
+   if (p_report->while_executing() && s==hk_presentation::viewmode) return;
     if (s==hk_presentation::viewmode)
     {
         if (!p_report->set_mode(s))
@@ -458,6 +463,8 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
     {                                             //design mode
 //setCaption(QString::fromUtf8(l2u(p_report->hk_presentation::name()).c_str()));
 
+	if (p_report->while_executing())
+	  p_report->stop_execution();
 	p_report->set_mode(s);
 	p_printaction->setEnabled(false);
         //createGUI(NULL);
@@ -650,9 +657,9 @@ void hk_kdereportpartwidget::hide_widget(void)
   hide();
 }
 
-void hk_kdereportpartwidget::close_widget(void)
+bool hk_kdereportpartwidget::close_widget(void)
 {
-  close();
+  return close();
 }
 
 void hk_kdereportpartwidget::set_caller_form(const hk_string&f)
