@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.125 $
+//$Revision: 1.129 $
 #include "hk_kdesimpleform.h"
 #include "hk_kdeform.h"
 #include "hk_kdeformpartwidget.h"
@@ -838,7 +838,7 @@ void hk_kdesimpleform::move_widgets(int xdiff,int ydiff)
         it++;
        }
   p_focus->set_positions();
-  p_property->focus_resized();
+  if (p_property)p_property->focus_resized();
 
 
   v=dynamic_cast<hk_visible*>(wid);
@@ -1781,7 +1781,6 @@ bool    hk_kdesimpleform::set_mode(enum_mode s)
 {
     if (p_private->while_modechange)
     {
-      cerr <<"rejected because while_modechange"<<endl;
      return true;
     }
     p_private->while_modechange=true;
@@ -2422,9 +2421,13 @@ void hk_kdesimpleform::hide_widget(void)
   hide();
 }
 
-void hk_kdesimpleform::close_widget(void)
+bool hk_kdesimpleform::close_widget(void)
 {
-  close();
+
+if (p_formpartwidget) return p_formpartwidget->close();
+else if (p_kdeform) return p_kdeform->close();
+else
+return close();
 }
 
 void hk_kdesimpleform::set_create_with_label(bool w)
