@@ -28,7 +28,7 @@ class  KActionCollection;
 /**
  *
  *@short KDE Widget to display forms.
- *@version $Revision: 1.53 $
+ *@version $Revision: 1.54 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *hk_kdesimpleform is a KDE widget to display and alter forms.
@@ -69,7 +69,7 @@ virtual void set_focus(hk_visible*);
 	void	hide();
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
         void set_create_with_label(bool);
         bool create_with_label(void) const;
 
