@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.133 $
+//$Revision: 1.135 $
 
 #include "hk_kdesimplegrid.h"
 #include "hk_kdesimplegrid.moc"
@@ -23,7 +23,6 @@
 #include "hk_kdesimpleform.h"
 #include "hk_kdegrid.h"
 #include "hk_kdegridcolumndialog.h"
-#include "hk_dsgridcolumn.h"
 #include "hk_kdememo.h"
 
 #include <list>
@@ -973,7 +972,6 @@ bool hk_kdesimplegrid::datasource_disable(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimplegrid::datasource_disable");
 #endif
-    cerr <<"datasource_disable()"<<endl;
     ensureCellVisible(0,0);
     widget_specific_enable_disable();
     setNumCols(1);
