@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.73 $
+//$Revision: 1.76 $
 
 #include "hk_kdesimplereport.h"
 #include "hk_kdereportsection.h"
@@ -33,6 +33,7 @@
 #include <qdragobject.h>
 #include <qclipboard.h>
 #include <qcolor.h>
+#include <qapplication.h>
 
 const int headerheight=20;
 class hk_kdesimplereportprivate
@@ -77,6 +78,7 @@ bool while_modechange;
         KAction* p_aligntopaction;
         KAction* p_alignbottomaction;
 	KDockWidget* p_propertydock;
+        double pix_je_cm;
 
 };
 
@@ -114,6 +116,8 @@ hk_kdesimplereport::hk_kdesimplereport (QWidget* parent,  const char* name, WFla
     p_private->p_property=NULL;
     p_private->p_focussection=NULL;
     p_private->p_progressdialog=NULL;
+    p_private->pix_je_cm=(QApplication::desktop()->screenGeometry(this).width()/1024.0)*32.0 ;
+
     set_reporttype("Postscript",false);
     //create_propertyeditor();
     //p_private->p_property->show();
@@ -316,6 +320,8 @@ bool hk_kdesimplereport::reporteventFilter(QObject* object,QEvent* event)
 //hkdebug("hk_kdesimpleform::formeventFilter");
 #endif
 
+
+
     QWidget* widget= (QWidget*) object;
 
     switch (event->type())
@@ -419,15 +425,15 @@ bool hk_kdesimplereport::reporteventFilter(QObject* object,QEvent* event)
                         {
                             if (sizetype()==hk_presentation::relative)
 			    {
-			    if ( widget->y()+widget->height()-difference.y()>(signed)relativ2vertical(border_top())*32.0/100+0.5)
+			    if ( widget->y()+widget->height()-difference.y()>(signed)relativ2vertical(border_top())*p_private->pix_je_cm/100+0.5)
                                                   //limits size of header section
-                                difference.setY((int)-(relativ2vertical(border_top())*32.0/100-widget->y()-widget->height()+0.5));
+                                difference.setY((int)-(relativ2vertical(border_top())*p_private->pix_je_cm/100-widget->y()-widget->height()+0.5));
                              }
 			   else
 			   {
-			    if ( widget->y()+widget->height()-difference.y()>(signed)border_top()*32.0/100+0.5)
+			    if ( widget->y()+widget->height()-difference.y()>(signed)border_top()*p_private->pix_je_cm/100+0.5)
                                                   //limits size of header section
-                                difference.setY((int)-(border_top()*32.0/100-widget->y()-widget->height()+0.5));
+                                difference.setY((int)-(border_top()*p_private->pix_je_cm/100-widget->y()-widget->height()+0.5));
 
 			   }
 			}
@@ -435,15 +441,15 @@ bool hk_kdesimplereport::reporteventFilter(QObject* object,QEvent* event)
                         {
                             if (sizetype()==hk_presentation::relative)
 			    {
-                            if ( widget->y()+widget->height()-difference.y()>(signed)relativ2vertical(border_bottom())*32.0/100+0.5)
+                            if ( widget->y()+widget->height()-difference.y()>(signed)relativ2vertical(border_bottom())*p_private->pix_je_cm/100+0.5)
                                                   //limits size of footer section
-                                difference.setY((int)-(relativ2vertical(border_bottom())*32.0/100-widget->y()-widget->height()+0.5));
+                                difference.setY((int)-(relativ2vertical(border_bottom())*p_private->pix_je_cm/100-widget->y()-widget->height()+0.5));
                             }
 			    else
 			    {
-                            if ( widget->y()+widget->height()-difference.y()>(signed)border_bottom()*32.0/100+0.5)
+                            if ( widget->y()+widget->height()-difference.y()>(signed)border_bottom()*p_private->pix_je_cm/100+0.5)
                                                   //limits size of footer section
-                                difference.setY((int)-(border_bottom()*32.0/100-widget->y()-widget->height()+0.5));
+                                difference.setY((int)-(border_bottom()*p_private->pix_je_cm/100-widget->y()-widget->height()+0.5));
                             }
 			}
                     }
@@ -794,7 +800,6 @@ void hk_kdesimplereport::keyPressEvent ( QKeyEvent * event )
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimplereport::keyPressEvent");
 #endif
-   const unsigned int pix_je_cm=32 ;
      switch(event->key())
     {
 //        case Key_Control:  p_private->p_controlbutton=true;
@@ -811,7 +816,7 @@ void hk_kdesimplereport::keyPressEvent ( QKeyEvent * event )
                unsigned int diff=(event->state()&ControlButton?1:snap2gridx());
                diff=(unsigned int)(sizetype()==hk_presentation::relative?
 	       				(p_private->p_focussection?((double)diff*10000)/ p_private->p_focussection->max_displaywidth()+0.5:diff):
-		     			((double)diff*100)/pix_je_cm+0.5);
+		     			((double)diff*100)/p_private->pix_je_cm+0.5);
         if (widget->x()>=diff) widget->set_x(widget->x()-diff);
               }
 
@@ -828,7 +833,7 @@ if (widget)
 unsigned int diff=(event->state()&ControlButton?1:snap2gridx());
                diff=(unsigned int)(sizetype()==hk_presentation::relative?
 	       				(p_private->p_focussection?((double)diff*10000)/ p_private->p_focussection->max_displaywidth()+0.5:diff):
-		     			((double)diff*100)/pix_je_cm+0.5);
+		     			((double)diff*100)/p_private->pix_je_cm+0.5);
 if (widget->x()+widget->width()+diff<=10000) widget->set_x(widget->x()+diff);
 }
 
@@ -845,7 +850,7 @@ if (widget)
 unsigned int diff=(event->state()&ControlButton?1:snap2gridy());
                diff=(unsigned int)(sizetype()==hk_presentation::relative?
 	       				(p_private->p_focussection?((double)diff*10000)/ p_private->p_focussection->max_displayheight()+0.5:diff):
-		     			((double)diff*100)/pix_je_cm+0.5);
+		     			((double)diff*100)/p_private->pix_je_cm+0.5);
 if (widget->y()>=diff) widget->set_y(widget->y()-diff);
 }
 
@@ -862,7 +867,7 @@ if (widget &&p_private->p_focussection)
 unsigned int diff=(event->state()&ControlButton?1:snap2gridy());
                diff=(unsigned int)(sizetype()==hk_presentation::relative?
 	       				(p_private->p_focussection?((double)diff*10000)/ p_private->p_focussection->max_displayheight()+0.5:diff):
-		     			((double)diff*100)/pix_je_cm+0.5);
+		     			((double)diff*100)/p_private->pix_je_cm+0.5);
 if (p_private->p_focussection==page_header()||p_private->p_focussection==page_footer())
 {
 if (p_private->p_focussection==page_header())
@@ -1390,7 +1395,7 @@ void hk_kdesimplereport::show_property(void)
 	 QPixmap p;
 	 p_private->p_propertydock=p_private->p_kdereport->createDockWidget("Property editor",p,0L,"");
 	 p_private->p_propertydock->setWidget(p_private->p_property);
-	 p_private->p_propertydock->manualDock(p_private->p_kdereport->getMainDockWidget(),KDockWidget::DockRight);
+	 p_private->p_propertydock->manualDock(p_private->p_kdereport->getMainDockWidget(),KDockWidget::DockRight,67);
 	}
 	else
 	if (p_private->p_reportpartwidget)
@@ -1398,7 +1403,7 @@ void hk_kdesimplereport::show_property(void)
 	 QPixmap p;
 	 p_private->p_propertydock=p_private->p_reportpartwidget->createDockWidget("Property editor",p,0L,"");
 	 p_private->p_propertydock->setWidget(p_private->p_property);
-	 p_private->p_propertydock->manualDock(p_private->p_reportpartwidget->getMainDockWidget(),KDockWidget::DockRight);
+	 p_private->p_propertydock->manualDock(p_private->p_reportpartwidget->getMainDockWidget(),KDockWidget::DockRight,67);
 	}
 
        newproperty=true;
