@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.8 $
+//$Revision: 1.9 $
 #include "hk_kdespinbox.h"
 #include <hk_string.h>
 #include <hk_class.h>
@@ -111,7 +111,7 @@ int hk_kdespinbox::mapTextToValue(bool* s)
      
     if (p_displaytype!=percent&&p_displaytype!=cm) return QSpinBox::mapTextToValue(s);
 
-    hk_string txt=cleanText().local8Bit().data();
+    hk_string txt=u2l(cleanText().utf8().data());
     double n=standardstring2double(txt);
     return (int) (100 * n+0.5);
 }
