@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.39 $
+//$Revision: 1.44 $
 
 #include "hk_kdetabledesign.h"
 #include "hk_kdetabledesign.moc"
@@ -44,6 +44,7 @@ hk_kdetabledesign::hk_kdetabledesign( QWidget* parent,  const char* name, WFlags
 : QWidget( parent, name, fl )  ,hk_dsvisible()
 {
 #ifdef HK_DEBUG
+//wanna_debug(true);
     hkclassname("hk_kdetabledesign");
     hkdebug("hk_kdetabledesign::hk_kdetabledesign");
 #endif
@@ -54,7 +55,7 @@ hk_kdetabledesign::hk_kdetabledesign( QWidget* parent,  const char* name, WFlags
     hk_kdetabledesignLayout = new QGridLayout( this );
     hk_kdetabledesignLayout->setSpacing( 6 );
     hk_kdetabledesignLayout->setMargin( 11 );
-    actualfieldit==NULL;
+    actualfieldit=fields.end();
 
     indexwindow=new QListView(this,"indexwindow");
     indexwindow->addColumn( i18n( "Index" ) );
@@ -201,7 +202,7 @@ hk_kdetabledesign::hk_kdetabledesign( QWidget* parent,  const char* name, WFlags
 
     primaryfield = new QCheckBox( this, "primaryfield" );
     primaryfield->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, primaryfield->sizePolicy().hasHeightForWidth() ) );
-    primaryfield->setEnabled(false);
+    primaryfield->setEnabled(true);
     Layout23->addWidget( primaryfield );
     QSpacerItem* spacer_4 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout23->addItem( spacer_4 );
@@ -212,7 +213,7 @@ hk_kdetabledesign::hk_kdetabledesign( QWidget* parent,  const char* name, WFlags
     Layout25->setMargin( 0 );
     notnullfield = new QCheckBox( this, "notnullfield" );
     notnullfield->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, notnullfield->sizePolicy().hasHeightForWidth() ) );
-    notnullfield->setEnabled(false);
+    notnullfield->setEnabled(true);
     QSpacerItem* spacer_5 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     Layout25->addWidget( notnullfield );
     Layout25->addItem( spacer_5 );
@@ -288,9 +289,9 @@ void hk_kdetabledesign::create_columntypelist(void)
 	notnullfield->setEnabled(false);
 	namefield->setEnabled(false);
 	deletebutton->setEnabled(false);
-	
-	
-	
+
+
+
     }
     if (datasource()!=NULL)
         if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_MEMOCOLUMN))
@@ -298,7 +299,7 @@ void hk_kdetabledesign::create_columntypelist(void)
 
         ftypename= i18n( "Memo" );
         typefield->insertItem(ftypename  );
-        dict.name=ftypename.local8Bit().data();
+        dict.name=ftypename;
         dict.type=hk_column::memocolumn;
         columntype_dictionary.insert(columntype_dictionary.end(),dict);
     }
@@ -364,7 +365,7 @@ void hk_kdetabledesign::create_columntypelist(void)
 
         ftypename= i18n( "Time" );
         typefield->insertItem(ftypename  );
-        dict.name=ftypename.local8Bit().data();
+        dict.name=ftypename;
         dict.type=hk_column::timecolumn;
         columntype_dictionary.insert(columntype_dictionary.end(),dict);
     }
@@ -545,7 +546,7 @@ void hk_kdetabledesign::delete_clicked()
     QListViewItem* f=fieldlist->currentItem();
 
     QListViewItem* p=NULL;
-    if (f==NULL||actualfieldit==NULL)  return;
+    if (f==NULL||actualfieldit==fields.end())  return;
     f->itemBelow();
 
     if ((*actualfieldit).state!=newfield)
@@ -595,11 +596,11 @@ void hk_kdetabledesign::new_clicked()
         numint++;
         n=nn+num;
     }
-    while (fieldname_count(n.local8Bit().data())!=0);
+    while (fieldname_count(u2l(n.utf8().data()))!=0);
     QString t=i18n("Text");
     QListViewItem* feld=new QListViewItem(fieldlist,n,t,"50",i18n("no"),i18n("no"));
     fieldstruct f;
-    f.oldname=f.newname=n.local8Bit().data();
+    f.oldname=f.newname=u2l(n.utf8().data());
     f.oldtype=f.newtype=hk_column::textcolumn;
     f.oldsize=f.newsize=50;
     f.oldprimary=f.newprimary=false;
@@ -615,8 +616,8 @@ void hk_kdetabledesign::new_clicked()
 void hk_kdetabledesign::name_changed()
 {
     QListViewItem* i=fieldlist->currentItem();
-    if (i==NULL||actualfieldit==NULL)return;
-    (*actualfieldit).newname=namefield->text().local8Bit().data();
+    if (i==NULL||actualfieldit==fields.end())return;
+    (*actualfieldit).newname=u2l(namefield->text().utf8().data());
     if ((*actualfieldit).state!=newfield&&(*actualfieldit).state!=delfield) (*actualfieldit).state=altered;
     i->setText(0,namefield->text());
     structure_changes(true);
@@ -626,7 +627,7 @@ void hk_kdetabledesign::name_changed()
 void hk_kdetabledesign::primary_changed()
 {
     QListViewItem* i=fieldlist->currentItem();
-    if (i==NULL||actualfieldit==NULL)return;
+    if (i==NULL||actualfieldit==fields.end())return;
     (*actualfieldit).newprimary=primaryfield->isChecked();
     if ((*actualfieldit).state!=newfield&&(*actualfieldit).state!=delfield) (*actualfieldit).state=altered;
     QString a=primaryfield->isChecked()?i18n("yes"):i18n("no");
@@ -638,7 +639,7 @@ void hk_kdetabledesign::primary_changed()
 void hk_kdetabledesign::notnull_changed()
 {
     QListViewItem* i=fieldlist->currentItem();
-    if (i==NULL||actualfieldit==NULL)return;
+    if (i==NULL||actualfieldit==fields.end())return;
     (*actualfieldit).newnotnull=notnullfield->isChecked();
     if ((*actualfieldit).state!=newfield&&(*actualfieldit).state!=delfield) (*actualfieldit).state=altered;
     QString a=notnullfield->isChecked()?i18n("yes"):i18n("no");
@@ -651,7 +652,7 @@ void hk_kdetabledesign::notnull_changed()
 void hk_kdetabledesign::size_changed()
 {
     QListViewItem* i=fieldlist->currentItem();
-    if (i==NULL||actualfieldit==NULL)return;
+    if (i==NULL||actualfieldit==fields.end())return;
     (*actualfieldit).newsize=sizefield->value();
     i->setText(2,sizefield->text());
     structure_changes(true);
@@ -663,7 +664,7 @@ void hk_kdetabledesign::size_changed()
 void hk_kdetabledesign::type_changed()
 {
     QListViewItem* i=fieldlist->currentItem();
-    if (i==NULL||actualfieldit==NULL)return;
+    if (i==NULL||actualfieldit==fields.end())return;
     if ((*actualfieldit).state!=newfield&&(*actualfieldit).state!=delfield) (*actualfieldit).state=altered;
     (*actualfieldit).newtype=ftype(typefield->currentText());
     i->setText(1,typefield->currentText());
@@ -708,7 +709,7 @@ void hk_kdetabledesign::selection_changed()
 
     if (lastmarkedItem!=NULL &&lastmarkedItem!=i)
     {
-        if ((fieldname_count(lastmarkedItem->text(0).local8Bit().data())>1||lastmarkedItem->text(0).length()==0)
+        if ((fieldname_count(u2l(lastmarkedItem->text(0).utf8().data()))>1||lastmarkedItem->text(0).length()==0)
             &&fieldnamecheck)
         {
             fieldnamecheck=false;
@@ -748,7 +749,7 @@ void hk_kdetabledesign::selection_changed()
 
     list<fieldstruct>::iterator it=fields.begin();
     bool found=false;
-    hk_string nn=i->text(0).local8Bit().data();
+    hk_string nn=u2l(i->text(0).utf8().data());
     while (it!=fields.end()&&!found)
     {
         if ((*it).newname==nn)
@@ -769,7 +770,8 @@ void hk_kdetabledesign::selection_changed()
     notnullfield->blockSignals(false);
     typefield->blockSignals(false);
     lastmarkedItem=fieldlist->currentItem();
-set_fields_enabled();
+    if (datasource())namefield->setMaxLength(datasource()->database()->connection()->maxfieldnamesize());
+    set_fields_enabled();
 }
 
 
@@ -788,9 +790,9 @@ void hk_kdetabledesign::load_fieldinfo()
 #endif
     fieldlist->blockSignals(true);
     fieldlist->clear();
-    actualfieldit==NULL;
     lastmarkedItem=NULL;
     fields.erase(fields.begin(),fields.end());
+    actualfieldit=fields.end();
     hk_datasource* d=datasource();
     if (d==NULL)
     {
@@ -812,9 +814,9 @@ void hk_kdetabledesign::load_fieldinfo()
     {
         fieldstruct f;
 
-        QString n=QString::fromLocal8Bit((*it)->name().c_str());
+        QString n=QString::fromUtf8(l2u((*it)->name()).c_str());
         f.oldname=f.newname=(*it)->name().c_str();
-        QString t=QString::fromLocal8Bit((*it)->columntype_name().c_str());
+        QString t=QString::fromUtf8(l2u((*it)->columntype_name()).c_str());
         QString s;
         s=s.setNum((*it)->size());
         f.oldsize=f.newsize=(*it)->size();
@@ -851,7 +853,11 @@ void hk_kdetabledesign::load_fieldinfo()
 	namefield->setEnabled(res);
 	newbutton->setEnabled(res);
 	deletebutton->setEnabled(res);
-
+	if (res)
+	{
+	 primaryfield->setEnabled(datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_ALTER_PRIMARY_KEY));
+	 notnullfield->setEnabled(datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_ALTER_NOT_NULL));
+	}
 
     }
     else
@@ -881,7 +887,7 @@ void hk_kdetabledesign::alter_index()
 
     while (it!=ilist->end() &&!found)
     {
-        hk_string r= indexwindow->currentItem()->text(0).local8Bit().data();
+        hk_string r= u2l(indexwindow->currentItem()->text(0).utf8().data());
         if ((*it).name==r) found=true;
         else  it++;
     }
@@ -900,7 +906,7 @@ void hk_kdetabledesign::alter_index()
 void hk_kdetabledesign::delete_index()
 {
     if (datasource()==NULL){ return; }
-    hk_string r= indexwindow->currentItem()->text(0).local8Bit().data();
+    hk_string r= u2l(indexwindow->currentItem()->text(0).utf8().data());
     datasource()->drop_index(r.c_str());
 
 }
@@ -938,7 +944,7 @@ void hk_kdetabledesign::set_indexlist(void)
     while (it!=ilist->end())
     {
         QListViewItem* feld=NULL;
-        feld=new QListViewItem(indexwindow,QString::fromLocal8Bit((*it).name.c_str()),(*it).unique?i18n("yes"):i18n("no"));
+        feld=new QListViewItem(indexwindow,QString::fromUtf8(l2u((*it).name).c_str()),(*it).unique?i18n("yes"):i18n("no"));
         it++;
     }
     indexwindow->setSelected(indexwindow->firstChild(),true);
@@ -974,7 +980,7 @@ void hk_kdetabledesign::structure_changes(bool c)
         res=(datasource()&&
         (datasource()->database()->connection()->
 	server_supports(hk_connection::SUPPORTS_NEW_TABLE)));
-      else  	
+      else
         res=(datasource()&&
         (datasource()->database()->connection()->
 	server_supports(hk_connection::SUPPORTS_ALTER_TABLE)));
@@ -984,8 +990,20 @@ void hk_kdetabledesign::structure_changes(bool c)
     primaryfield->setEnabled(res);
     notnullfield->setEnabled(res);
     sizefield->setEnabled(res);
-    deletebutton->setEnabled(res); 
-
+    deletebutton->setEnabled(res);
+   if (res)
+   {
+        if (datasource() && datasource()->name().size()>0)
+        {
+	 primaryfield->setEnabled(datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_ALTER_PRIMARY_KEY));
+	 notnullfield->setEnabled(datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_ALTER_NOT_NULL));
+        }
+        else
+        {
+	 primaryfield->setEnabled(true);
+	 notnullfield->setEnabled(true);
+        }
+   }
 }
 
 
@@ -1051,7 +1069,7 @@ void hk_kdetabledesign::show_fieldinfos(fieldstruct* f)
 
 void hk_kdetabledesign::set_fields_enabled(void)
 {
-    if (actualfieldit==NULL)return;
+    if (actualfieldit==fields.end())return;
     sizefield->setEnabled((*actualfieldit).newtype==hk_column::textcolumn);
 
 }
