@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.7 $
+//$Revision: 1.8 $
 
 #include "hk_kdetablepartwidget.h"
 #include <hk_datasource.h>
@@ -324,8 +324,8 @@ void hk_kdetablepartwidget::hide_widget(void)
   hide();
 }
 
-void hk_kdetablepartwidget::close_widget(void)
+bool hk_kdetablepartwidget::close_widget(void)
 {
-  close();
+  return close();
 }
 
