@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -18,16 +18,28 @@
 #include <qpushbutton.h>
 #include <kfiledialog.h>
 #include <klocale.h>
+#include <hk_database.h>
+#include <hk_connection.h>
+#include <qprogressdialog.h>
 #include <kapplication.h>
 #include <kconfig.h>
 
+
+
+QProgressDialog* hk_kdexmlexportdialog::p_progressdialog=NULL;
+bool    hk_kdexmlexportdialog::p_cancelimport=false;
+
+
+
+
+
 hk_kdexmlexportdialog::hk_kdexmlexportdialog(const QString& table, QWidget* parent,  const char* name, bool modal, WFlags fl )
 : hk_kdexmlexportdialogbase( parent, name, modal, fl ), hk_reportxml()
 {
     p_tablename=table;
     p_datasourcetype=dt_table;
-    maindocumenttagfield->setText(QString::fromLocal8Bit(maindocumenttag().c_str()));
-    rowelementfield->setText(QString::fromLocal8Bit(rowtag().c_str()));
+    maindocumenttagfield->setText(QString::fromUtf8(l2u(maindocumenttag()).c_str()));
+    rowelementfield->setText(QString::fromUtf8(l2u(rowtag()).c_str()));
     structurefield->setChecked(includetableschema());
     structurefield->setText(i18n("include tableschema?"));
   KConfig* c=kapp->config();
@@ -47,19 +59,35 @@ hk_kdexmlexportdialog::~hk_kdexmlexportdialog()
 
 void hk_kdexmlexportdialog::ok_clicked()
 {
-    set_filename(filefield->text().local8Bit().data());
-    long ds=new_datasource(tablenamefield->currentText().local8Bit().data(),p_datasourcetype);
+    set_filename(u2l(filefield->text().utf8().data()));
+    long ds=new_datasource(u2l(tablenamefield->currentText().utf8().data()),p_datasourcetype);
     set_presentationdatasource(ds);
-    set_maindocumenttag(maindocumenttagfield->text().local8Bit().data());
-    set_rowtag(rowelementfield->text().local8Bit().data());
+    set_maindocumenttag(u2l(maindocumenttagfield->text().utf8().data()));
+    set_rowtag(u2l(rowelementfield->text().utf8().data()));
     set_includetableschema(structurefield->isChecked());
     set_fieldname_as_attribute(attributefield->isChecked()?fieldnameattribute:fieldname);
+    p_cancelimport=false;
+   p_progressdialog= new  QProgressDialog(this,NULL,true);
+   p_progressdialog->setCaption(i18n("Exporting data..."));
+   p_progressdialog->setTotalSteps(100);
+   connect(p_progressdialog,SIGNAL(cancelled()),this,SLOT(printing_cancelled()));
+   p_progressdialog->show();
+   qApp->processEvents();
     if ( execute()) accept();
-KConfig* c=kapp->config();
+    delete p_progressdialog;
+  p_progressdialog=NULL;
+
+  KConfig* c=kapp->config();
   c->setGroup("XMLExport");
   c->writeEntry("Geometry",geometry());
 }
 
+void hk_kdexmlexportdialog::printing_cancelled(void)
+{
+    cout <<"cancelclicked"<<endl;
+    p_cancelimport=true;
+
+}
 
 void hk_kdexmlexportdialog::buttons_enabled()
 {
@@ -75,7 +103,7 @@ void hk_kdexmlexportdialog::buttons_enabled()
 
 void hk_kdexmlexportdialog::filebutton_clicked()
 {
-    p_file = KFileDialog::getOpenFileName( QString::null, QString::null, this,i18n("Select a XML file"));
+    p_file = KFileDialog::getOpenFileName( ":xml", QString::null, this,i18n("Select a XML file"));
     filefield->setText(p_file);
 }
 
@@ -133,9 +161,62 @@ void hk_kdexmlexportdialog::set_datasourcelist(void)
     {
         for(it=tbl->begin();it!=tbl->end();it++)
         {
-            tablenamefield->insertItem(QString::fromLocal8Bit((*it).c_str()));
+            tablenamefield->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
             if (!p_tablename.isEmpty()&& p_tablename==(*it).c_str()) tablenamefield->setCurrentItem(tablenamefield->count()-1);
         }
     }
 
 }
+
+
+void hk_kdexmlexportdialog::listtype_changed()
+{
+switch (typefield->currentItem())
+{
+ case 1: p_datasourcetype=dt_query;break;
+ case 2: p_datasourcetype=dt_view;break;
+ default: p_datasourcetype=dt_table;
+}
+set_datasourcelist();
+}
+
+
+void hk_kdexmlexportdialog::set_database(hk_database* d)
+{
+    typefield->clear();
+    typefield->insertItem(i18n("Table"));
+    typefield->insertItem(i18n("Query"));
+    hk_presentation::set_database(d);
+    if (d && d->connection()->server_supports(hk_connection::SUPPORTS_VIEWS))
+    {
+        typefield->insertItem(i18n("View"));
+
+    }
+    set_datasourcelist();
+}
+
+
+void hk_kdexmlexportdialog::help_clicked()
+{
+kapp->invokeHelp("exportxml");
+}
+
+bool hk_kdexmlexportdialog::set_progress(long int position,long int total,const hk_string&txt)
+{
+    if (p_progressdialog)
+    {
+
+        p_progressdialog->setCaption(QString::fromUtf8(l2u(txt).c_str()));
+        p_progressdialog->setTotalSteps(total);
+        p_progressdialog->setProgress(position);
+        p_progressdialog->raise();
+        qApp->processEvents();
+    }
+    return p_cancelimport;
+}
+
+void hk_kdexmlexportdialog::keyPressEvent ( QKeyEvent * e )
+{
+  if (e->key()==Key_F1) help_clicked();
+}
+
