@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.46 $
+//$Revision: 1.47 $
 #include "knodamaindockwindow.h"
 #include "hk_kdedblistview.h"
 #include "hk_kdecsvimportdialog.h"
@@ -103,7 +103,7 @@ knodamaindockwindow::~knodamaindockwindow()
 
 void knodamaindockwindow::slot_childClosed(QWidget* w)
 {
- cerr <<"slot_childClosed(QWidget* w)"<<endl;
+//  cerr <<"slot_childClosed(QWidget* w)"<<endl;
  if (!w)
  {
    cerr<<"knodamaindockwindow::slot_childClosed\nWARNING! w==NULL"<<endl;
@@ -121,12 +121,12 @@ void knodamaindockwindow::slot_childClosed(QWidget* w)
 
  void knodamaindockwindow::slot_childClosed(KMdiChildView* /*c*/)
  {
-  cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c)"<<endl;
+//   cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c)"<<endl;
 
 
 
 
-  cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c) ENDE"<<endl;
+//   cerr <<"knodamaindockwindow::slot_childClosed(KMdiChildView* c) ENDE"<<endl;
  }
 
 
