@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.14 $
+//$Revision: 1.17 $
 #ifndef KNODAMAINDOCKWINDOW_H
 #define KNODAMAINDOCKWINDOW_H
 #include "knodamaindockwindowbase.h"
@@ -18,7 +18,7 @@ class hk_kdequerypartwidget;
 class hk_kdeformpartwidget;
 class hk_kdereportpartwidget;
 
-
+typedef void show_dbfunction(int);
 
 class knodamaindockwindow : public knodamaindockwindowbase
 {
@@ -82,13 +82,24 @@ virtual void newwindow_clicked(void);
  void slot_childClosed(KMdiChildView*);
 virtual void settings_clicked(void);
 virtual void show_drivers();
+virtual void show_exportdbdrivers();
+virtual void show_importdbdrivers();
  
-  
+ void slot_raise_form(const hk_string&); 
  protected slots:
  
  void slot_selection_changed(void);
  
+ 
  private:
+ enum enum_function{f_connect,f_exportdb,f_importdb};
+ void show_drivers(KPopupMenu* menu, enum_function);
+hk_kdeformpartwidget* find_existing_form(const hk_string& n);
+hk_kdereportpartwidget* find_existing_report(const hk_string& n);
+hk_kdetablepartwidget* find_existing_table(const hk_string& n);
+hk_kdequerypartwidget* find_existing_query(const hk_string& n);
+hk_kdequerypartwidget* find_existing_view(const hk_string& n);
+
 };
 
 
