@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.12 $
+//$Revision: 1.13 $
 
 //***********************************************
 //***  hk_kdequery PART definition             ***
@@ -124,9 +124,9 @@ hk_kdequerypart::hk_kdequerypart(QWidget* pWidget, const char* /*widgetname*/,QO
 }
 
 hk_kdequerypart::~hk_kdequerypart()
-{cerr <<"delete query part"<<endl;
+{
   if (widget())
-  {cerr <<"save query"<<endl;
+  {
     if (p_private->p_query->has_changed())
      p_private->p_query->save_query();
   }
@@ -172,7 +172,6 @@ p_private->p_query->kdeqbe()->add_datasource();
 
 void hk_kdequerypart::qbetypeselect_action(int t)
 {
-cerr <<"hk_kdeqbepart::qbetypeselect_action"<<endl;
  hk_qbe::enum_querytype ntype=hk_qbe::qt_select;
  switch (t)
  {
