@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -23,6 +23,7 @@
 #include <qimage.h>
 #include <qpixmap.h>
 #include <hk_classes.h>
+#include <hk_connection.h>
 #include "hk_kdepreferencesdialog.h"
 #include <kaboutapplication.h>
 #include <kconfig.h>
@@ -34,60 +35,14 @@
 #include <kstandarddirs.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kfiledialog.h>
 
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <algorithm>
-#include <qworkspace.h>
 #include <qvbox.h>
 #include <kiconloader.h>
 
-  hk_kdeworkspace::hk_kdeworkspace(QWidget* parent , const char* name , WFlags fl)
-  :KMainWindow(parent,name,fl), hk_class()
-  {
-    p_vbox=new QVBox(this);
-    //p_vbox->setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
-    p_workspace=new QWorkspace(p_vbox);
-    p_workspace->setScrollBarsEnabled( TRUE );
-    p_mainwindow=NULL;
-    setCentralWidget(p_vbox);
-//    createGUI(0L);
-KIconLoader* loader=KGlobal::iconLoader();
-    loader->addAppDir("hk_kdeclasses");
-        KStdAction::close(this,SLOT(close()),actionCollection());
-
-     new KAction(i18n("Show database window"),loader->loadIcon("propertyeditor",KIcon::User),0,this,SLOT(showdb_clicked()),actionCollection(),"showdb");
-     new KAction(i18n("Exit"),"fileclose",0,this,SLOT(close()),actionCollection(),"quit");
-    resize(790,600);
-
-    QString rcfile=locate("data","knoda/hk_kdeworkspace.rc");
-    createGUI(rcfile);
-    p_workspace->setBackgroundMode( PaletteMid);
-    p_workspace->setScrollBarsEnabled(true);
-  }
-
-
-
-
-  hk_kdeworkspace::~hk_kdeworkspace()
-  {
-   delete p_mainwindow;
-  }
-
-
-void hk_kdeworkspace::showdb_clicked(void)
-{
-if (p_mainwindow->parentWidget())
-    p_mainwindow->parentWidget()->move(10,10);
-if (p_workspace->activeWindow()&&p_workspace->activeWindow()->isMaximized())
-  {
-     p_mainwindow->hide();
-     p_mainwindow->showNormal();
-  }
-else p_mainwindow->show();
-p_mainwindow->parentWidget()->raise();
-}
-
 
 
 
@@ -95,24 +50,23 @@ p_mainwindow->parentWidget()->raise();
  *  Constructs a knodaprogrambase which is a child of 'parent', with the
  *  name 'name' and widget flags set to 'f'.
  */
-knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags fl, const hk_string& driver,const QString& database,const QString& form,bool runtime ,bool with_workspace, bool classiclook )
+knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags fl,struct_commandlinefields* cl )
 : QWidget( parent, name, fl )
 {
-    p_selecteddb=database;
-    p_selectedform=form;
-    p_runtime=runtime;
-    p_useworkspace=with_workspace;
-    p_driver=driver;
-    p_docklook=(!classiclook);
+    p_selecteddb=QString::fromUtf8(l2u(cl->database).c_str());
+    p_selectedform=QString::fromUtf8(l2u(cl->form).c_str());
+    p_runtime=cl->runtime_only;
+    p_driver=cl->driver;
+    p_load_connection=cl->p_guicommands->p_load_connection;
     if ( !name )
         setName( "knodaprogrambase" );
     resize( 350, 241 );
-    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)4, 0, 0, sizePolicy().hasHeightForWidth() ) );
+    setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::MinimumExpanding, 0, 0, sizePolicy().hasHeightForWidth() ) );
     setMinimumSize( QSize( 350, 240 ) );
-    setMaximumSize( QSize( 32767, 250 ) );
+    setMaximumSize( QSize( 32767, 290 ) );
 //setCaption( trUtf8( "Knoda" ) );
     knodaprogrambaseLayout = new QHBoxLayout( this, 11, 6, "knodaprogrambaseLayout");
-
+    QVBoxLayout* leftlayout=new QVBoxLayout(this,0,0,"leftlayout");
     logolabel = new QLabel( this, "logolabel" );
     logolabel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, logolabel->sizePolicy().hasHeightForWidth() ) );
     logolabel->setMinimumSize( QSize( 219, 219 ) );
@@ -126,13 +80,16 @@ knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags f
     logolabel->setLineWidth( 1 );
     logolabel->setScaledContents( FALSE );
     logolabel->setAlignment( int( QLabel::AlignCenter ) );
-    knodaprogrambaseLayout->addWidget( logolabel );
+    knodaprogrambaseLayout->addLayout(leftlayout);
+    QSpacerItem* spacer=new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+    leftlayout->addItem( spacer );
+    leftlayout->addWidget( logolabel );
 
     ButtonGroup1 = new QButtonGroup( this, "ButtonGroup1" );
     ButtonGroup1->setFrameShape( QButtonGroup::NoFrame );
     ButtonGroup1->setColumnLayout(0, Qt::Vertical );
     ButtonGroup1->layout()->setSpacing( 5 );
-    ButtonGroup1->layout()->setMargin( 4 );
+    ButtonGroup1->layout()->setMargin( 0 );
     ButtonGroup1Layout = new QVBoxLayout( ButtonGroup1->layout() );
     ButtonGroup1Layout->setAlignment( Qt::AlignTop );
 
@@ -140,7 +97,7 @@ knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags f
     driverlist->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)0, 0, 0, driverlist->sizePolicy().hasHeightForWidth() ) );
     driverlist->setMinimumSize( QSize( 100, 0 ) );
     ButtonGroup1Layout->addWidget( driverlist );
-    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+    spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
     ButtonGroup1Layout->addItem( spacer );
 
     connectbutton = new KPushButton( ButtonGroup1, "connectbutton" );
@@ -148,6 +105,11 @@ knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags f
     connectbutton->setText( trUtf8( "&Connect" ) );
     ButtonGroup1Layout->addWidget( connectbutton );
 
+    loadconnectionbutton = new KPushButton( ButtonGroup1, "loadconnectionbutton" );
+    loadconnectionbutton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)1, 0, 0, loadconnectionbutton->sizePolicy().hasHeightForWidth() ) );
+    loadconnectionbutton->setText( trUtf8( "&Load" ) );
+    ButtonGroup1Layout->addWidget( loadconnectionbutton );
+
     quitbutton = new KPushButton( ButtonGroup1, "quitbutton" );
     quitbutton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)1, 0, 0, quitbutton->sizePolicy().hasHeightForWidth() ) );
     quitbutton->setText( trUtf8( "&Quit" ) );
@@ -168,6 +130,7 @@ knodaprogrambase::knodaprogrambase( QWidget* parent,  const char* name, WFlags f
     connect( optionbutton, SIGNAL( clicked() ), this, SLOT( options_clicked() ) );
     connect( quitbutton, SIGNAL( clicked() ), this, SLOT( quit_clicked() ) );
     connect( connectbutton, SIGNAL( clicked() ), this, SLOT( connect_clicked() ) );
+    connect( loadconnectionbutton, SIGNAL( clicked() ), this, SLOT( loadconnection_clicked() ) );
     connect( aboutbutton, SIGNAL( clicked() ), this, SLOT( about_clicked() ) );
     p_drivermanager =new hk_drivermanager(p_runtime);
     set_databaselist();
@@ -201,7 +164,7 @@ void knodaprogrambase::about_clicked()
  */
 void knodaprogrambase::connect_clicked()
 {
-    if (p_driver.size()>0)
+    if (!p_load_connection && p_driver.size()>0)
     {
         vector<hk_string>::iterator it=std::find(p_drivermanager->driverlist()->begin(),p_drivermanager->driverlist()->end(),p_driver);
         if (it==p_drivermanager->driverlist()->end())
@@ -214,10 +177,30 @@ void knodaprogrambase::connect_clicked()
 
         }
     }
-    hk_connection* c=p_drivermanager->new_connection(driverlist->currentText().local8Bit().data());
+    hk_connection* c=NULL;
+      bool use_passwddialog=true;
+    if (p_load_connection)
+    {
+      hk_database* db=p_drivermanager->open_connectionfile(u2l(p_selecteddb.utf8().data()));
+      if (db)
+      {
+        hk_string dbname=db->name();
+        p_selecteddb=QString::fromUtf8(l2u(dbname).c_str());
+        c=db->connection();
+        p_load_connection=false;
+        use_passwddialog=false;
+        p_driver="";
+      }
+      else
+        show_warningmessage(hk_class::hk_translate("Database could not be loaded"));
+
+    }
+    else
+    c=p_drivermanager->new_connection(u2l(driverlist->currentText().utf8().data()));
     if (c!=NULL)
     {
-        if (!c->show_passworddialog())
+
+        if (use_passwddialog &&!c->show_passworddialog())
         {
             delete c;
             c=NULL;
@@ -231,16 +214,8 @@ void knodaprogrambase::connect_clicked()
 	       w->show();
 	       return;
 	    }*/
-	    hk_kdeworkspace* sp=NULL;
-	    if (p_useworkspace)sp=new hk_kdeworkspace(0,0,WDestructiveClose);
-            knodamainwindow* w=new knodamainwindow((sp?sp->p_workspace:0L),sp,0,(sp?0:WDestructiveClose),p_selecteddb,p_selectedform);
-   	    if (sp)
-	    {
-	    sp->p_mainwindow=w;
-            sp->show();
-	    hk_string s=c->drivername()+" "+c->user()+"@"+c->host()+":"+ulongint2string(c->tcp_port());
-            sp->setCaption(QString::fromLocal8Bit(s.c_str()));
-	    }
+            knodamainwindow* w=new knodamainwindow(0L,0,WDestructiveClose,p_selecteddb,p_selectedform);
+            p_selecteddb="";
 	    w->show();
             w->set_connection(c);
 		if (w->parentWidget())w->parentWidget()->move(10,10);
@@ -257,18 +232,45 @@ void knodaprogrambase::connect_clicked()
 }
 
 
+
+void knodaprogrambase::loadconnection_clicked()
+{
+  if (!p_drivermanager) return;
+  QStringList l;
+  QString xmime="application/x-hk_connection";
+  l.append(xmime);
+KFileDialog* d=new KFileDialog(":hkc",QString::null,this,0,true);
+d->setMimeFilter(l,xmime);
+d->exec();
+QString filename=d->selectedFile();
+  if (!filename.isNull())
+  {
+//execute new connection
+   p_selecteddb=filename;
+   p_load_connection=true;
+   connect_clicked();
+  }
+   delete d;
+
+}
+
+
+
+
+
+
 void knodaprogrambase::options_clicked()
 {
     hk_kdepreferencesdialog* p_dialog= new hk_kdepreferencesdialog(0,0,true);
-    p_dialog->timefield->setText(QString::fromLocal8Bit(hk_class::defaulttimeformat().c_str())),
-    p_dialog->datefield->setText(QString::fromLocal8Bit(hk_class::defaultdateformat().c_str())),
-    p_dialog->datetimefield->setText(QString::fromLocal8Bit(hk_class::defaultdatetimeformat().c_str()));
-    p_dialog->localefield->setText(QString::fromLocal8Bit(hk_class::locale().c_str()));
-    p_dialog->printcommandfield->setText(QString::fromLocal8Bit(hk_report::printcommand().c_str()));
-    p_dialog->driverpathfield->setText(QString::fromLocal8Bit(hk_drivermanager::path().c_str()));
+    p_dialog->timefield->setText(QString::fromUtf8(l2u(hk_class::defaulttimeformat()).c_str())),
+    p_dialog->datefield->setText(QString::fromUtf8(l2u(hk_class::defaultdateformat()).c_str())),
+    p_dialog->datetimefield->setText(QString::fromUtf8(l2u(hk_class::defaultdatetimeformat()).c_str()));
+    p_dialog->localefield->setText(QString::fromUtf8(l2u(hk_class::locale()).c_str()));
+    p_dialog->printcommandfield->setText(QString::fromUtf8(l2u(hk_report::printcommand()).c_str()));
+    p_dialog->driverpathfield->setText(QString::fromUtf8(l2u(hk_drivermanager::path()).c_str()));
     p_dialog->bepedanticfield->setCurrentItem(hk_class::showpedantic()?0:1);
     p_dialog->maximizedfield->setCurrentItem(hk_visible::open_maximized_windows()?0:1);
-    p_dialog->fontfield->setEditText(QString::fromLocal8Bit(hk_font::defaultfontname().c_str()));
+    p_dialog->fontfield->setEditText(QString::fromUtf8(l2u(hk_font::defaultfontname()).c_str()));
     p_dialog->fontsizefield->setValue(hk_font::defaultfontsize());
     p_dialog->precisionfield->setValue(hk_dsdatavisible::defaultprecision());
     p_dialog->separatorfield->setCurrentItem(hk_dsdatavisible::defaultuse_numberseparator()?0:1);
@@ -281,23 +283,13 @@ void knodaprogrambase::options_clicked()
     int di=0;
     for(it=drv->begin();it!=drv->end();it++)
     {
-        p_dialog->defaultdriverfield->insertItem(QString::fromLocal8Bit((*it).c_str()));
+        p_dialog->defaultdriverfield->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
         if ((*it)==hk_class::defaultdriver())
             p_dialog->defaultdriverfield->setCurrentItem(di);
         di++;
     }
 
-    list<hk_string>* encodelist =hk_report::fontencodinglist();
-    p_dialog->encodingfield->clear();
-    list<hk_string>::iterator eit=encodelist->begin();
     int i=0;
-    while (eit!=encodelist->end())
-    {
-        p_dialog->encodingfield->insertItem(QString::fromLocal8Bit((*eit).c_str()));
-        if ((*eit)==hk_report::fontencodingstring()) p_dialog->encodingfield->setCurrentItem(i);
-        eit++;
-        i++;
-    }
 
     switch (hk_visible::defaulttextalignment())
     {
@@ -320,17 +312,16 @@ void knodaprogrambase::options_clicked()
     if (res==QDialog::Accepted)
     {
         hk_class::set_defaultdatetimeformat(
-            p_dialog->timefield->text().local8Bit().data(),
-            p_dialog->datefield->text().local8Bit().data(),
-            p_dialog->datetimefield->text().local8Bit().data()
+            u2l(p_dialog->timefield->text().utf8().data()),
+            u2l(p_dialog->datefield->text().utf8().data()),
+            u2l(p_dialog->datetimefield->text().utf8().data())
             );
-	 hk_class::set_locale(p_dialog->localefield->text().local8Bit().data());
+	 hk_class::set_locale(u2l(p_dialog->localefield->text().utf8().data()));
         hk_class::set_showpedantic( p_dialog->bepedanticfield->currentItem()==0);
         hk_visible::set_open_maximized_windows(p_dialog->maximizedfield->currentItem()==0);
-        hk_report::set_fontencoding(p_dialog->encodingfield->currentText().local8Bit().data());
-        hk_report::set_printcommand(p_dialog->printcommandfield->text().local8Bit().data());
-        hk_drivermanager::set_path(p_dialog->driverpathfield->text().local8Bit().data());
-        hk_font::set_defaultfont(p_dialog->fontfield->currentText().local8Bit().data(),p_dialog->fontsizefield->value());
+        hk_report::set_printcommand(u2l(p_dialog->printcommandfield->text().utf8().data()));
+        hk_drivermanager::set_path(u2l(p_dialog->driverpathfield->text().utf8().data()));
+        hk_font::set_defaultfont(u2l(p_dialog->fontfield->currentText().utf8().data()),p_dialog->fontsizefield->value());
 	hk_presentation::set_snap2gridx(p_dialog->snap2gridxfield->value());
 	hk_presentation::set_snap2gridy(p_dialog->snap2gridyfield->value());
         hk_visible::alignmenttype a=hk_visible::alignleft;
@@ -353,7 +344,7 @@ void knodaprogrambase::options_clicked()
         }
         hk_visible::set_defaultnumberalignment(a);
         hk_dsdatavisible::set_defaultnumberformat(p_dialog->separatorfield->currentItem()==0,p_dialog->precisionfield->value());
-        hk_class::set_defaultdriver(p_dialog->defaultdriverfield->currentText().local8Bit().data());
+        hk_class::set_defaultdriver(u2l(p_dialog->defaultdriverfield->currentText().utf8().data()));
 
         hk_class::save_preferences();
         set_databaselist();
@@ -374,7 +365,7 @@ void knodaprogrambase::set_databaselist()
     int i=0;
     for(it=drv->begin();it!=drv->end();it++)
     {
-        driverlist->insertItem(QString::fromLocal8Bit((*it).c_str()));
+        driverlist->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
         if ((p_driver.size()==0 &&(*it)==hk_class::defaultdriver())||(*it)==p_driver)
             driverlist->setCurrentItem(i);
         i++;
