@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of knoda -Knorr's Datenbank.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.57 $
+//$Revision: 1.60 $
 
 #include "knodawin.h"
 #include "knodawinbase.h"
@@ -16,22 +16,31 @@
 #include <kaction.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <qworkspace.h>
+#include <kconfig.h>
+#include <kapplication.h>
+
 #include "knodaprogrambase.h"
 
-knodamainwindow::knodamainwindow( QWidget* parent,hk_kdeworkspace* w,  const char* name, WFlags fl,const QString& database,const QString& form )
+knodamainwindow::knodamainwindow( QWidget* parent,  const char* name, WFlags fl,const QString& database,const QString& form )
 : KMainWindow( parent, name, fl ) ,hk_class()
 {
     //setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)3, sizePolicy().hasHeightForWidth() ) );
     setMinimumSize( QSize( 400, 450 ) );
-    if (w)setMaximumSize( QSize( 400, 450 ) );
     KIconLoader* loader=KGlobal::iconLoader();
     loader->addAppDir("hk_kdeclasses");
 //   setXMLFile("knodaui.rc");
     p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(close_slot()),actionCollection(),"closedatabase");
 
-    p_mainwindow = new knodamainwindowbase(this,w,name,fl,database,form);
+    p_mainwindow = new knodamainwindowbase(this,name,fl,database,form);
     setCentralWidget(p_mainwindow);
+  KConfig* c=kapp->config();
+  adjustSize();
+  QRect rect(0,0,width(),height());
+  c->setGroup("knodaclassic");
+  QRect g;
+  g=c->readRectEntry("Geometry",&rect);
+  setGeometry(g);
+
 
 //createGUI(0L);
 }
@@ -50,12 +59,15 @@ void knodamainwindow::set_connection(hk_connection* c)
     if (c)
     {
         hk_string s=c->drivername()+" "+c->user()+"@"+c->host()+":"+ulongint2string(c->tcp_port());
-        setCaption(QString::fromLocal8Bit(s.c_str()));
+        setCaption(QString::fromUtf8(l2u(s).c_str()));
     }
 
 }
 void knodamainwindow::closeEvent(QCloseEvent*event)
 {
+  KConfig* c=kapp->config();
+  c->setGroup("knodaclassic");
+  c->writeEntry("Geometry",geometry());
  if (p_mainwindow)
   {
  if (p_mainwindow->database())
@@ -69,20 +81,20 @@ void knodamainwindow::closeEvent(QCloseEvent*event)
       hk_report* r=dynamic_cast<hk_report*>(*it);
       if (r)
       {
-        if (r->while_executing()) 
+        if (r->while_executing())
 	  {
 	   while_printing=true;
 	   n=r->name();
-	  } 
+	  }
       }
-      
+
       ++it;
      }
-   
+
      if (while_printing)
      {
        show_warningmessage(replace_all("%1",hk_translate("Cannot close now, because the report '%1' is executing. Cancel it first"),n));
-       
+
      event->ignore();
      }
      else
@@ -96,9 +108,9 @@ void knodamainwindow::closeEvent(QCloseEvent*event)
 
 void knodamainwindow::close_slot(void)
 {
- 
+
     close();
-  
+
 }
 
 
